Module sync

Module sync 

Structs

Next
Borrowed access to a node’s successor slots.
Node
Intrusive, reference-counted list node.
NodeIter
A local iterator that walks the ring that a node is a component of.
UniqueNodeIter
Local iterator that walks a ring once, starting from a given node.
WeakNode
Non-owning view of a Node<T> sharing the weak count.

Traits

RawExt