Structs
- Next
- Borrowed access to a node’s successor slots.
- Node
- Intrusive, reference-counted list node.
- Node
Iter - A local iterator that walks the ring that a node is a component of.
- Unique
Node Iter - Local iterator that walks a ring once, starting from a given node.
- Weak
Node - Non-owning view of a
Node<T>sharing the weak count.